@@ -68,6 +68,33 @@ class TestAPI(object):
         assert_equals(len(list(self.operator.get_condition_sets())), 3,
                       self.operator)
 
+    @patch('switchboard.signals.switch_checked.send')
+    def test_switch_checked_signal(self, send):
+        condition_set = 'switchboard.builtins.IPAddressConditionSet'
+        key = 'test'
+
+        switch = Switch.create(
+            key=key,
+            status=SELECTIVE,
+        )
+        switch = self.operator[key]
+        req = Request.blank('/')
+
+        result = self.operator.is_active(key, req)
+        assert_false(result)
+        send.assert_called_with(key, active=result)
+
+        switch.add_condition(
+            condition_set=condition_set,
+            field_name='ip_address',
+            condition='192.168.1.1',
+        )
+        req.environ['REMOTE_ADDR'] = '192.168.1.1'
+
+        result = self.operator.is_active(key, req)
+        assert_true(result)
+        send.assert_called_with(key, active=result)
+
     @patch('switchboard.base.MongoModelDict.get_default')
     def test_error(self, get_default):
         # force the is_active call to fail right away
@@ -136,8 +163,10 @@ class TestAPI(object):
 
         req = Request.blank('/')
         req.environ['REMOTE_ADDR'] = '192.168.1.1'
+        original_func = self.operator.get_request
+        self.operator.get_request = lambda: req
 
-        @switch_is_active('test', req, operator=self.operator)
+        @switch_is_active('test', operator=self.operator)
         def test():
             return True
 
@@ -202,6 +231,7 @@ class TestAPI(object):
         )
 
         assert_raises(HTTPNotFound, test)
+        self.operator.get_request = original_func
 
     def test_decorator_with_redirect(self):
         Switch.create(
@@ -210,12 +240,15 @@ class TestAPI(object):
         )
 
         req = Request.blank('/')
+        original_func = self.operator.get_request
+        self.operator.get_request = lambda: req
 
-        @switch_is_active('test', req, redirect_to='/foo')
+        @switch_is_active('test', redirect_to='/foo')
         def test():
             return True
 
         assert_raises(HTTPFound, test)
+        self.operator.get_request = original_func
 
     def test_global(self):
         switch = Switch.create(
